@@ -96,4 +96,4 @@ OC.L10N.register(
     "Birthday" : "Fecha de nacimiento",
     "User not found" : "No se encontró el usuario"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
