@@ -11,6 +11,7 @@ OC.L10N.register(
     "Cheers!" : "سلامتی!",
     "Upcoming events" : "رویدادهای پیش‌رو",
     "Appointments" : "قرارها",
+    "Confirm" : "تائید",
     "Date:" : "تاریخ:",
     "Where:" : "مکان:",
     "Calendar" : "تقویم",
@@ -21,11 +22,15 @@ OC.L10N.register(
     "Next day" : "روز بعد",
     "Next week" : "هفته بعد",
     "Next month" : "ماه بعد",
+    "New event" : "رویداد جدید",
     "Today" : "امروز",
     "Day" : "روز",
     "Week" : "هفته",
     "Month" : "ماه",
     "List" : "لیست",
+    "Preview" : "پیش‌نمایش",
+    "Copy link" : "کپی کردن لینک",
+    "Edit" : "ویرایش",
     "Delete" : "حذف",
     "Untitled calendar" : "تقویم بدون عنوان",
     "Edit name" : "ویرایش نام",
@@ -33,6 +38,7 @@ OC.L10N.register(
     "Edit color" : "ویرایش رنگ",
     "Saving color …" : "ذخیره رنگ",
     "Copy private link" : "کپی کردن پیوند خصوصی",
+    "Export" : "گرفتن خروجی",
     "Unshare from me" : "بی خبر از من",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
     "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
@@ -80,6 +86,10 @@ OC.L10N.register(
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
     "Trash bin" : "زباله‌دان",
     "Name" : "نام",
+    "Deleted" : "حذف شده",
+    "Restore" : "بازیابی",
+    "Delete permanently" : "حذف قطعی",
+    "Empty trash bin" : "خالی کردن سطل زباله",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -90,6 +100,7 @@ OC.L10N.register(
     "Automatic" : "خودکار",
     "Automatic ({detected})" : "خودکار ({شناسایی})",
     "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
+    "List view" : "نمایش لیست",
     "Actions" : "فعالیت ها",
     "Enable birthday calendar" : "تقویم تولد را فعال کنید",
     "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
@@ -102,9 +113,19 @@ OC.L10N.register(
     "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "Location" : "محل",
     "Description" : "توضیحات",
+    "Duration" : "مدت زمان",
+    "to" : "به",
+    "Add" : "افزودن",
     "Monday" : "دوشنبه",
+    "Tuesday" : "سه شنبه",
+    "Wednesday" : "چهارشنبه",
+    "Thursday" : "پنجشنبه",
+    "Friday" : "جمعه",
+    "Saturday" : "شنبه",
+    "Sunday" : "یکشنبه",
     "Save" : "ذخیره",
     "Update" : "به روز رسانی",
+    "Your email address" : "پست الکترونیکی شما",
     "before at" : "قبل از در",
     "Notification" : "اطلاع",
     "Email" : "ایمیل",
@@ -123,18 +144,22 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ساعت","ساعت ها"],
     "_day_::_days_" : ["روز","روز ها"],
     "_week_::_weeks_" : ["هفته","هفته ها"],
+    "Available" : "در دسترس",
     "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
     "Free" : "رایگان",
     "Busy (tentative)" : "مشغول (آزمایشی)",
     "Busy" : "مشغول",
     "Out of office" : "بیرون از دفتر",
     "Unknown" : "نامشخص",
+    "Accept" : "تایید",
+    "Decline" : "کاهش می یابد",
     "Tentative" : "آزمایشی",
     "Create Talk room for this event" : "اتاق گفتگو را برای این رویداد ایجاد کنید",
     "Show busy times" : " نمایش  زمان‌های  شلوغ",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
     "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
+    "Send email" : "ارسال ایمیل",
     "Chairperson" : "رئیس",
     "Required participant" : "شرکت کننده مورد نیاز",
     "Optional participant" : "شرکت کننده اختیاری",
@@ -170,6 +195,7 @@ OC.L10N.register(
     "weekday" : "روز هفته",
     "weekend day" : " آخر  هفته",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
+    "available" : "در دسترس",
     "More" : "بیش‌تر",
     "Update this occurrence" : "این رویداد را به روز کنید",
     "Update this and all future" : "این و همه آینده را به روز کنید",
@@ -190,10 +216,10 @@ OC.L10N.register(
     "Delete this and all future" : "این و همه آینده را حذف کنید",
     "Details" : "جزئیات",
     "Attendees" : "شرکت کنندگان",
+    "Resources" : "منابع",
     "Close" : "بستن",
     "Show more details" : "جزئیات بیشتر را نشان دهید",
     "Subscribe to {name}" : "اشتراک در {name}",
-    "Download {name}" : "بارگیری {name}",
     "Anniversary" : "سالگرد",
     "Appointment" : "وقت ملاقات",
     "Business" : "کسب و کار",
@@ -238,7 +264,11 @@ OC.L10N.register(
     "until {untilDate}" : "تا زمان {untilDate}",
     "_%n time_::_%n times_" : ["%n بار","%n بارها"],
     "Untitled event" : "رویداد بدون عنوان",
+    "Prev" : "مقدمه",
+    "Next" : "بعدی",
+    "Year" : "سال",
     "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
+    "Other" : "اعلان‌ها",
     "When shared show" : "هنگام نمایش مشترک",
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
@@ -263,6 +293,7 @@ OC.L10N.register(
     "Relaxing" : "آرامش بخش",
     "Relax" : "آروم باش",
     "Presentation" : "ارائه",
+    "Talk" : "گفتگو",
     "Camping" : "چادر زدن",
     "Camp" : "اردوگاه",
     "Movie" : "فیلم",
@@ -299,6 +330,7 @@ OC.L10N.register(
     "Doctor" : "دکتر",
     "Health" : "سلامتی",
     "Dentist" : "دندانپزشک",
+    "Hospital" : "بیمارستان",
     "Interview" : "مصاحبه",
     "Training" : "آموزش",
     "Practice" : "تمرین",
@@ -332,12 +364,14 @@ OC.L10N.register(
     "Party" : "مهمانی - جشن",
     "Celebration" : "جشن",
     "Celebrate" : "جشن گرفتن",
+    "Birthday" : "روزتولد",
     "Shopping" : "خريد كردن",
     "Skate" : "اسکیت",
     "Skateboard" : "صفحه اسکیت",
     "Wine tasting" : "مزه کردن شراب",
     "Golf" : "گلف",
     "Dinner" : "شام",
-    "Lunch" : "ناهار"
+    "Lunch" : "ناهار",
+    "User not found" : "کاربر یافت نشد"
 },
 "nplurals=2; plural=(n > 1);");
