@@ -3,13 +3,24 @@ OC.L10N.register(
     {
     "Provided email-address is not valid" : "Oppgitt e-postadresse er ikke gyldig",
     "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
+    "Unexpected error sending email. Please contact your administrator." : "Det oppstod uventet feil under sending av e-post. Kontakt din administrator.",
+    "Successfully sent email to %1$s" : "Epost sendt til %1$s",
     "Hello," : "Hei,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
     "Open »%s«" : "Åpne \"%s\"",
     "Cheers!" : "Ha det!",
     "Upcoming events" : "Kommende hendelser",
     "Appointments" : "Avtaler",
+    "Schedule appointment \"%s\"" : "Registrer avtale \"%s\"",
+    "Schedule an appointment" : "Registrer en avtale",
+    "Prepare for %s" : "Forbered for %s",
+    "Follow up for %s" : "Følg opp for %s",
+    "Your appointment \"%s\" needs confirmation" : "Avtalen din \"%s\" trenger bekreftelse",
+    "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bookingen din",
     "Confirm" : "Bekreft",
+    "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
+    "If you wish to cancel the appointment after all, please contact your organizer." : "Hvis du ønsker å avlyse avtalen likevel, vennligst kontakt arrangøren din.",
+    "Appointment:" : "Avtale:",
     "Date:" : "Dato:",
     "Where:" : "Hvor:",
     "Description:" : "Beskrivelse:",
@@ -31,7 +42,12 @@ OC.L10N.register(
     "Copy link" : "Kopier lenke",
     "Edit" : "Rediger",
     "Delete" : "Slett",
+    "Appointment link was copied to clipboard" : "Avtalelenke ble kopiert til utklippstavlen",
+    "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
+    "Add new" : "Legg til ny",
     "Untitled calendar" : "Kalender uten tittel",
+    "Disable calendar" : "Deaktiver kalender",
+    "Enable calendar" : "Aktiver kalender",
     "Edit name" : "Rediger navn",
     "Saving name …" : "Lagrer navn ...",
     "Edit color" : "Rediger farge",
@@ -77,6 +93,7 @@ OC.L10N.register(
     "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
     "+ New calendar" : "+ Ny kalender",
     "New calendar" : "Ny kalender",
+    "Name for new calendar" : "Navn på ny kalender",
     "Creating calendar …" : "Oppretter kalender ...",
     "New calendar with task list" : "Ny kalender med oppgaveliste",
     "New subscription from link (read-only)" : "Nytt abonnement fra lenke (kun lesing)",
@@ -84,11 +101,18 @@ OC.L10N.register(
     "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
     "Trash bin" : "Papirkurv",
+    "Loading deleted elements." : "Laster slettede elementer.",
+    "You do not have any deleted elements." : "Du har ingen slettede elementer.",
     "Name" : "Navn",
     "Deleted" : "Slettet",
     "Restore" : "Gjenoprett",
     "Delete permanently" : "Slett permament",
     "Empty trash bin" : "Tøm papirkurv",
+    "Untitled element" : "Element uten tittel",
+    "Unknown calendar" : "Ukjent kalender",
+    "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
+    "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
+    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendrene.",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
