@@ -24,16 +24,15 @@ declare(strict_types=1);
 namespace OCA\Calendar\AppInfo;
 
 use OCA\Calendar\Dashboard\CalendarWidget;
+use OCA\Calendar\Listener\UserDeletedListener;
+use OCA\Calendar\Profile\AppointmentsAction;
 use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
+use OCP\User\Events\UserDeletedEvent;
+use function method_exists;
 
-/**
- * Class Application
- *
- * @package OCA\Calendar\AppInfo
- */
 class Application extends App implements IBootstrap {
 
 	/** @var string */
@@ -51,6 +50,13 @@ class Application extends App implements IBootstrap {
 	 */
 	public function register(IRegistrationContext $context): void {
 		$context->registerDashboardWidget(CalendarWidget::class);
+
+		// TODO: drop conditional code when the app is 23+
+		if (method_exists($context, 'registerProfileLinkAction')) {
+			$context->registerProfileLinkAction(AppointmentsAction::class);
+		}
+
+		$context->registerEventListener(UserDeletedEvent::class, UserDeletedListener::class);
 	}
 
 	/**
